@@ -35,10 +35,10 @@ class SuccessPage : public QWizardPage, Ui::Success
     Q_OBJECT
 
 public:
-    explicit SuccessPage(BlueWizard *parent = 0);
+    explicit SuccessPage(BlueWizard *parent = nullptr);
 
-    int nextId() const Q_DECL_OVERRIDE;
-    void initializePage() Q_DECL_OVERRIDE;
+    int nextId() const override;
+    void initializePage() override;
 
 private:
     BlueWizard *m_wizard;
